@@ -10,11 +10,10 @@
  *******************************************************************************/
 /*eslint-env node */
 var express = require('express');
-var api = require('./api');
 
 module.exports = {};
 
-var BUILD_ID = "2017-05-04_11-15-39";
+var BUILD_ID = "2017-05-04_11-42-35";
 
 module.exports.router = function(options) {
 	var configParams = options.configParams;
@@ -23,7 +22,8 @@ module.exports.router = function(options) {
 	return express.Router()
 	.get('*', /* @callback */ function (req, res) {
 		var buildID = configParams["orion.buildId"] || BUILD_ID;
-		return api.writeResponse(200, res, null, {
+		res.setHeader("Cache-Control", "no-cache");
+		return res.status(200).json({
 			build: buildID
 		});
 	});
